@@ -6,6 +6,9 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "../../../libvips/include/vips/resample.h" */
+GType vips_kernel_get_type (void) G_GNUC_CONST;
+#define VIPS_TYPE_KERNEL (vips_kernel_get_type())
 /* enumerations from "../../../libvips/include/vips/foreign.h" */
 GType vips_foreign_flags_get_type (void) G_GNUC_CONST;
 #define VIPS_TYPE_FOREIGN_FLAGS (vips_foreign_flags_get_type())
