@@ -196,8 +196,24 @@ const guint64 vips__image_sizeof_bandformat[] = {
 guint64 
 vips_format_sizeof( VipsBandFormat format )
 {
-	g_assert( format >= 0 && 
-		format < VIPS_FORMAT_LAST ); 
+	format = VIPS_CLIP( 0, format, VIPS_FORMAT_DPCOMPLEX ); 
+
+	return( vips__image_sizeof_bandformat[format] );
+}
+
+/**
+ * vips_format_sizeof_unsafe: (skip)
+ * @format: format type
+ *
+ * A fast but dangerous version of vips_format_sizeof(). You must have
+ * previously range-checked @format or you'll crash.
+ *
+ * Returns: number of bytes for a band format.
+ */
+guint64 
+vips_format_sizeof_unsafe( VipsBandFormat format )
+{
+	g_assert( 0 <= format && format <= VIPS_FORMAT_DPCOMPLEX ); 
 
 	return( vips__image_sizeof_bandformat[format] );
 }
