@@ -2786,7 +2786,8 @@ vips_image_ispartial( VipsImage *image )
 int
 vips_image_write_prepare( VipsImage *image )
 {	
-	g_assert( vips_object_sanity( VIPS_OBJECT( image ) ) );
+	if( !vips_object_sanity( VIPS_OBJECT( image ) ) )
+		return( -1 ); 
 
 	if( image->Xsize <= 0 || 
 		image->Ysize <= 0 || 
@@ -3046,7 +3047,8 @@ vips_image_wio_input( VipsImage *image )
 {	
 	VipsImage *t1;
 
-	g_assert( vips_object_sanity( VIPS_OBJECT( image ) ) );
+	if( !vips_object_sanity( VIPS_OBJECT( image ) ) )
+		return( -1 ); 
 
 #ifdef DEBUG_IO
 	printf( "vips_image_wio_input: wio input for %s\n", 
@@ -3269,8 +3271,9 @@ vips_image_inplace( VipsImage *image )
  */
 int
 vips_image_pio_input( VipsImage *image )
-{	
-	g_assert( vips_object_sanity( VIPS_OBJECT( image ) ) );
+{
+	if( !vips_object_sanity( VIPS_OBJECT( image ) ) )
+		return( -1 ); 
 
 #ifdef DEBUG_IO
 	printf( "vips_image_pio_input: enabling partial input for %s\n", 
