@@ -177,6 +177,7 @@ vips_vector_new( const char *name, int dsize )
 #ifdef DEBUG_TRACE
 	printf( "%s = orc_program_new();\n", vector->unique_name );
 #endif /*DEBUG_TRACE*/
+#endif /*HAVE_ORC*/
 
 	/* We always make d1, our callers make either a single point source, or
 	 * for area ops, a set of scanlines.
@@ -185,14 +186,7 @@ vips_vector_new( const char *name, int dsize )
 	 * var you create will have id 0 :-( The first var is unlikely to fail
 	 * anyway. 
 	 */
-	vector->d1 = orc_program_add_destination( vector->program, 
-		dsize, "d1" );
-#ifdef DEBUG_TRACE
-	printf( "orc_program_add_destination( %s, %d, \"d1\" );\n", 
-		vector->unique_name, dsize ); 
-#endif /*DEBUG_TRACE*/
-	vector->n_destination += 1;
-#endif /*HAVE_ORC*/
+	vector->d1 = vips_vector_destination( vector, "d1", dsize ); 
 
 	return( vector );
 }
@@ -274,29 +268,6 @@ vips_vector_constant( VipsVector *vector, char *name, int value, int size )
 #endif /*HAVE_ORC*/
 }
 
-int
-vips_vector_source_name( VipsVector *vector, char *name, int size )
-{
-	int var;
-
-#ifdef HAVE_ORC
-	g_assert( orc_program_find_var_by_name( vector->program, name ) == -1 );
-
-	if( !(var = orc_program_add_source( vector->program, size, name )) )
-		vips_vector_error( vector ); 
-	vector->s[vector->n_source] = var;
-#ifdef DEBUG_TRACE
-	printf( "orc_program_add_source( %s, %d, \"%s\" );\n", 
-		vector->unique_name, size, name );
-#endif /*DEBUG_TRACE*/
-	vector->n_source += 1;
-#else /*!HAVE_ORC*/
-	var = -1;
-#endif /*HAVE_ORC*/
-
-	return( var );
-}
-
 void
 vips_vector_source_scanline( VipsVector *vector, 
 	char *name, int line, int size )
@@ -321,8 +292,31 @@ vips_vector_source_scanline( VipsVector *vector,
 #endif /*HAVE_ORC*/
 }
 
+int
+vips_vector_source_name( VipsVector *vector, const char *name, int size )
+{
+	int var;
+
+#ifdef HAVE_ORC
+	g_assert( orc_program_find_var_by_name( vector->program, name ) == -1 );
+
+	if( !(var = orc_program_add_source( vector->program, size, name )) )
+		vips_vector_error( vector ); 
+	vector->s[vector->n_source] = var;
+#ifdef DEBUG_TRACE
+	printf( "orc_program_add_source( %s, %d, \"%s\" );\n", 
+		vector->unique_name, size, name );
+#endif /*DEBUG_TRACE*/
+	vector->n_source += 1;
+#else /*!HAVE_ORC*/
+	var = -1;
+#endif /*HAVE_ORC*/
+
+	return( var );
+}
+
 void
-vips_vector_temporary( VipsVector *vector, char *name, int size )
+vips_vector_temporary( VipsVector *vector, const char *name, int size )
 {
 #ifdef HAVE_ORC
 	g_assert( orc_program_find_var_by_name( vector->program, name ) == -1 );
@@ -338,6 +332,51 @@ vips_vector_temporary( VipsVector *vector, char *name, int size )
 #endif /*HAVE_ORC*/
 }
 
+int
+vips_vector_parameter( VipsVector *vector, const char *name, int size )
+{
+	int var;
+
+#ifdef HAVE_ORC
+	g_assert( orc_program_find_var_by_name( vector->program, name ) == -1 );
+
+	var = orc_program_add_parameter( vector->program, size, name );
+	if( !var )
+		vips_vector_error( vector ); 
+
+#ifdef DEBUG_TRACE
+	printf( "orc_program_add_parameter( %s, %d, \"%s\" );\n",
+		vector->unique_name, size, name );
+#endif /*DEBUG_TRACE*/
+	vector->n_parameter += 1;
+#else /*!HAVE_ORC*/
+	var = -1;
+#endif /*HAVE_ORC*/
+
+	return ( var ); 
+}
+
+int
+vips_vector_destination( VipsVector *vector, const char *name, int size )
+{
+	int var;
+
+#ifdef HAVE_ORC
+	g_assert( orc_program_find_var_by_name( vector->program, name ) == -1 );
+
+	var = orc_program_add_destination( vector->program, size, name );
+#ifdef DEBUG_TRACE
+	printf( "orc_program_add_destination( %d, \"%s\" );\n",
+		size, name );
+#endif /*DEBUG_TRACE*/
+	vector->n_destination += 1;
+#else /*!HAVE_ORC*/
+	var = -1;
+#endif /*HAVE_ORC*/
+
+	return( var ); 
+}
+
 gboolean
 vips_vector_full( VipsVector *vector )
 {
@@ -351,12 +390,17 @@ vips_vector_full( VipsVector *vector )
 	if( vector->n_constant + 2 > 8 )
 		return( TRUE );
 
-	/* You can have 8 parameters, and d1 counts as one of them, so +1
+	/* You can have 8 source, and d1 counts as one of them, so +1
 	 * there.
 	 */
 	if( vector->n_source + vector->n_scanline + 1 > 7 )
 		return( TRUE );
 
+	/* Need to leave some space, so 1 spare. 
+	 */
+	if( vector->n_parameter > 7 )
+		return( TRUE );
+
 	/* After signalling full, some operations will add up to 4 more 
 	 * instructions as they finish up. Leave a margin.
 	 */
@@ -439,6 +483,15 @@ vips_executor_set_array( VipsExecutor *executor, int var, void *value )
 #endif /*HAVE_ORC*/
 }
 
+void
+vips_executor_set_parameter( VipsExecutor *executor, int var, int value )
+{
+#ifdef HAVE_ORC
+	if( var != -1 )  
+		orc_executor_set_param( &executor->executor, var, value );
+#endif /*HAVE_ORC*/
+}
+
 void
 vips_executor_set_scanline( VipsExecutor *executor, 
 	VipsRegion *ir, int x, int y )
@@ -449,10 +502,9 @@ vips_executor_set_scanline( VipsExecutor *executor,
 
 	int i;
 
-	for( i = 0; i < vector->n_scanline; i++ ) {
+	for( i = 0; i < vector->n_scanline; i++ ) 
 		vips_executor_set_array( executor, 
 			vector->sl[i], base + vector->line[i] * lsk );
-	}
 }
 
 void
