@@ -10,6 +10,9 @@
  * 	- shrink more affine less, now we have better anti-alias settings
  * 10/3/16
  * 	- revise again, using new vips_reduce() code
+ * 1/5/16
+ * 	- allow >1 on one axis, <1 on the other
+ * 	- expose @kernel setting
  */
 
 /*
@@ -67,6 +70,7 @@ typedef struct _VipsResize {
 
 	double scale;
 	double vscale;
+	VipsKernel kernel;
 
 	/* Deprecated.
 	 */
@@ -132,15 +136,20 @@ vips_resize_build( VipsObject *object )
 	else
 		int_vshrink = int_hshrink;
 
-	if( int_hshrink > 1 ||
-		int_vshrink > 1 ) { 
-		vips_info( class->nickname, "box shrink by %d x %d", 
-			int_hshrink, int_vshrink );
-		if( vips_shrink( in, &t[0], int_hshrink, int_vshrink, NULL ) )
+	if( int_vshrink > 1 ) { 
+		vips_info( class->nickname, "shrinkv by %d", int_vshrink );
+		if( vips_shrinkv( in, &t[0], int_vshrink, NULL ) )
 			return( -1 );
 		in = t[0];
 	}
 
+	if( int_hshrink > 1 ) { 
+		vips_info( class->nickname, "shrinkh by %d", int_hshrink );
+		if( vips_shrinkh( in, &t[1], int_hshrink, NULL ) )
+			return( -1 );
+		in = t[1];
+	}
+
 	/* Do we need a further size adjustment? It's the difference
 	 * between our target size and the size we have after vips_shrink().
 	 *
@@ -195,32 +204,49 @@ vips_resize_build( VipsObject *object )
 		in = t[6];
 	}
 
-	/* Any downsizing.
+	/* Any residual downsizing.
 	 */
-	if( hresidual < 1.0 || 
-		vresidual < 1.0 ) { 
-		vips_info( class->nickname, "residual reduce by %g x %g", 
-			hresidual, vresidual );
-
-		if( vips_reduce( in, &t[2], 
-			1.0 / hresidual, 1.0 / vresidual, NULL ) )  
+	if( vresidual < 1.0 ) { 
+		vips_info( class->nickname, "residual reducev by %g", 
+			vresidual );
+		if( vips_reducev( in, &t[2], 1.0 / vresidual, 
+			"kernel", resize->kernel, 
+			NULL ) )  
 			return( -1 );
 		in = t[2];
 	}
 
-	/* Any upsizing.
-	 */
-	if( hresidual > 1.0 || 
-		vresidual > 1.0 ) { 
-		vips_info( class->nickname, "residual scale %g x %g", 
-			hresidual, vresidual );
-		if( vips_affine( in, &t[3], hresidual, 0, 0, vresidual, 
-			"interpolate", vips_interpolate_nearest_static(), 
+	if( hresidual < 1.0 ) { 
+		vips_info( class->nickname, "residual reduceh by %g", 
+			hresidual );
+		if( vips_reduceh( in, &t[3], 1.0 / hresidual, 
+			"kernel", resize->kernel, 
 			NULL ) )  
 			return( -1 );
 		in = t[3];
 	}
 
+	/* Any upsizing.
+	 */
+	if( hresidual > 1.0 ) { 
+		vips_info( class->nickname, "residual scaleh %g", 
+			hresidual );
+		if( vips_affine( in, &t[4], hresidual, 0.0, 0.0, 1.0, 
+			"interpolate", vips_interpolate_nearest_static(), 
+			NULL ) )  
+			return( -1 );
+		in = t[4];
+	}
+
+	if( vresidual > 1.0 ) { 
+		vips_info( class->nickname, "residual scalev %g", vresidual );
+		if( vips_affine( in, &t[5], 1.0, 0.0, 0.0, vresidual, 
+			"interpolate", vips_interpolate_nearest_static(), 
+			NULL ) )  
+			return( -1 );
+		in = t[5];
+	}
+
 	if( vips_image_write( in, resample->out ) )
 		return( -1 ); 
 
@@ -259,6 +285,13 @@ vips_resize_class_init( VipsResizeClass *class )
 		G_STRUCT_OFFSET( VipsResize, vscale ),
 		0, 10000000, 0 );
 
+	VIPS_ARG_ENUM( class, "kernel", 3, 
+		_( "Kernel" ), 
+		_( "Resampling kernel" ),
+		VIPS_ARGUMENT_OPTIONAL_INPUT,
+		G_STRUCT_OFFSET( VipsResize, kernel ),
+		VIPS_TYPE_KERNEL, VIPS_KERNEL_LANCZOS3 );
+
 	/* We used to let people set the input offset so you could pick centre
 	 * or corner interpolation, but it's not clear this was useful. 
 	 */
@@ -291,6 +324,7 @@ vips_resize_class_init( VipsResizeClass *class )
 static void
 vips_resize_init( VipsResize *resize )
 {
+	resize->kernel = VIPS_KERNEL_LANCZOS3;
 }
 
 /**
@@ -303,21 +337,26 @@ vips_resize_init( VipsResize *resize )
  * Optional arguments:
  *
  * @vscale: vertical scale factor
+ * @kernel: #VipsKernel to reduce with 
  *
  * Resize an image. When upsizing (@scale > 1), the image is simply block
  * upsized. When downsizing, the
- * image is block-shrunk with vips_shrink(), then an anti-alias blur is
- * applied with vips_gaussblur(), then the image is shrunk again to the 
- * target size with vips_reduce(). 
+ * image is block-shrunk with vips_shrink(), 
+ * then the image is shrunk again to the 
+ * target size with vips_reduce(). The operation will leave at least the final
+ * x2 to be done with vips_reduce().
  *
  * vips_resize() normally maintains the image apect ratio. If you set
  * @vscale, that factor is used for the vertical scale and @scale for the
  * horizontal.
  *
+ * vips_resize() normally uses #VIPS_KERNEL_LANCZOS3 for thre final shrink, you
+ * can change this with @kernel.
+ *
  * This operation does not change xres or yres. The image resolution needs to
  * be updated by the application. 
  *
- * See also: vips_shrink(), vips_reduce(), vips_gaussblur().
+ * See also: vips_shrink(), vips_reduce().
  *
  * Returns: 0 on success, -1 on error
  */
